@@ -3,13 +3,9 @@ package Devel::AssertOS;
 use Devel::CheckOS;
 
 use strict;
+use warnings;
 
-use vars qw($VERSION);
-
-$VERSION = '1.21';
-
-# localising prevents the warningness leaking out of this module
-local $^W = 1;    # use warnings is a 5.6-ism
+our $VERSION = '1.21';
 
 =head1 NAME
 
