@@ -1,13 +1,30 @@
 package Devel::AssertOS::Linux;
 
 use Devel::CheckOS;
+use strict;
+use warnings;
+no warnings 'redefine';
 
-$VERSION = '1.2';
+our $VERSION = '1.3';
 
-sub os_is { $^O =~ /^linux$/i ? 1 : 0; }
+
+sub subtypes { qw(Android) }
+sub matches { ('Linux', subtypes()) }
+
+sub os_is {
+    (
+        # order is important
+        Devel::CheckOS::os_is(subtypes()) ||
+        $^O =~ /^linux$/i
+    ) ? 1 : 0;
+}
 
 Devel::CheckOS::die_unsupported() unless(os_is());
 
+sub expn {
+    "The operating system has a Linux kernel"
+}
+
 =head1 COPYRIGHT and LICENCE
 
 Copyright 2007 - 2014 David Cantrell
